# Generated by Django 2.2.8 on 2022-05-12 11:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0003_department_sort_num'),
    ]

    operations = [
        migrations.AlterField(
            model_name='department',
            name='sort_num',
            field=models.IntegerField(default=1, unique=True, verbose_name='部门排序'),
            preserve_default=False,
        ),
    ]
