# Generated by Django 2.2.8 on 2022-05-12 11:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0002_department_charger'),
    ]

    operations = [
        migrations.AddField(
            model_name='department',
            name='sort_num',
            field=models.IntegerField(null=True, unique=True, verbose_name='部门排序'),
        ),
    ]
