# Generated by Django 2.2.8 on 2022-06-10 15:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0011_auto_20220610_1549'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='userposition',
            table='middle_user_position_map',
        ),
        migrations.AlterModelTable(
            name='userrole',
            table='middle_user_roles_map',
        ),
    ]
