# Generated by Django 2.2.8 on 2022-06-10 16:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('departments', '0012_auto_20220610_1550'),
    ]

    operations = [
        migrations.AlterField(
            model_name='position',
            name='name',
            field=models.CharField(max_length=32, verbose_name='岗位名称'),
        ),
    ]
